import { TypeService, ICompanyItem } from '@/interface'
import { ref } from 'vue'

import type { FormRules } from 'element-plus'

export const currencyList = ref([
  {
    label: 'AUD',
    symbol: '',
    country: '',
  },
  {
    label: 'NZD',
    symbol: '',
    country: '',
  },
  {
    label: 'CNY',
    symbol: '¥',
    country: 'CN',
  },
  {
    label: 'GBP',
    symbol: '',
    country: '',
  },
  {
    label: 'EUR',
    symbol: '',
    country: '',
  },
  {
    label: 'USD',
    symbol: '',
    country: '',
  },
])

export const orderTypeList = ref([
  {
    label: '打样',
  },
  {
    label: '大货',
  },
])

export const formRule = ref<FormRules>({
  Order_Type: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  Artwork_Link: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  PO_Date: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  field7: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  field8: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  field6: [
    {
      required: true,
      message: '必填项',
      trigger: 'blur',
    },
  ],
  currentVendor: [
    {
      required: true,
      message: '必填项',
      trigger: 'change',
    },
  ],
})

export const emptyProductItem = {
  label: '',
  value: '',
  candidate: [],
  name: '',
  desc: '',
  id: '',
  quantity: '',
  rate: '',
  requirement: '',
  // 未计算优惠(discount)之前的总额
  amount: 0,
  // 优惠额度
  discount: '',
  // 库存
  Warehouse: '',
  // 用来区分是否 库存商品, 是则需要将库存选项设置为必选项
  CF_Product_Type: '',
}

export const getPath = function (path: string) {
  return new URL(path, import.meta.url).href
}

/**
 * 用于切换合同模版. Promo Collection 用户组使用.
 */
export const companyList = ref<ICompanyItem[]>([
  {
    id: 'PC',
    label: 'PC',
    name: '澳之原贸易有限公司',
    addr: 'UNIT 12,21/F WAYSON COMM BLDG NO 28 CONNAUGHT RD WEST SHEUNG WAN,HK',
    phone: '020-81609790',
    signPath: getPath('/assets/sign/AZY.png'),
  },
  // {
  //   id: 'Pangea',
  //   label: 'Pangea',
  //   name: '庞吉亚国际商务服务（广州）有限公司',
  //   addr: '广州市越秀区八旗二马路48号内自编1号主楼自编1605、1606房',
  //   phone: '020-81609790',
  //   fax: '020-81519492',
  //   signPath: getPath('/assets/sign/Pangea.png'),
  // },
  {
    id: 'PangeaTaxReimbursement',
    label: 'Pangea_退税版',
    name: '庞吉亚国际商务服务（广州）有限公司',
    addr: '广州市越秀区八旗二马路48号内自编1号主楼901、903、1307、1605、1606房',
    phone: '020-81609790',
    fax: '020-81519492',
    // 名字叫退税版, 实际上合同没有第二份pdf. 判断是否退税版的依据是键名存在与否, 而不是这个值的真假
    taxReimbursement: false,
    signPath: getPath('/assets/sign/Pangea.png'),
  },
  // {
  //   id: 'AZYTaxReimbursement',
  //   label: 'AZY_退税版',
  //   name: '澳之原贸易有限公司',
  //   addr: 'UNIT 12,21/F WAYSON COMM BLDG NO 28 CONNAUGHT RD WEST SHEUNG WAN,HK',
  //   phone: '020-81609790',
  //   taxReimbursement: true,
  //   signPath: getPath('/assets/sign/AZY.png'),
  // },
  {
    id: 'FOTTaxReimbursement',
    label: 'FOT_退税版',
    name: 'FAIR OCEAN TRADING AUSTRALIA PTY.LTD',
    addr: '15/10 Chilvers Road, Thornleigh, NSW 2120',
    phone: '020-81609790',
    taxReimbursement: true,
    signPath: getPath('/assets/sign/FOT.png'),
  },
])

/**
 * 用于切换合同模版. PrimePac 用户组的模版
 */
export const PrimePacList = ref<ICompanyItem[]>([
  {
    id: 'PrimePacCommon',
    label: 'PrimePac Purchase order 通用版',
    name: '澳之原贸易有限公司',
    addr: 'UNIT 12,21/F WAYSON COMM BLDG NO 28 CONNAUGHT RD WEST SHEUNG WAN,HK',
    phone: '020-81609790',
    signPath: getPath('/assets/sign/AZY.png'),
  },
  {
    id: 'PrimePacSoft',
    label: 'PrimePac Purchase order 软包版',
    name: '澳之原贸易有限公司',
    addr: 'UNIT 12,21/F WAYSON COMM BLDG NO 28 CONNAUGHT RD WEST SHEUNG WAN,HK',
    phone: '020-81609790',
    signPath: getPath('/assets/sign/AZY.png'),
  },
])

/**
 *  合同的服务条款
 */
export const serviceRule = ref<TypeService>({
  PC: [
    '一、本采购订单签署原件一式两份，双方各持一份。',
    '二、验收标准:按乙方所寄样板及国家出口标准作为验收标准。',
    '三、交货期限:交货期限必须严格执行。',
    '四、交货地点:甲方广州公司地址,如上收货地址。',
    '五、付款方式:甲方通过银行转帐的方式付款,乙方账户信息如上。',
    '六、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '七、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
  ],
  Pangea: [
    '一、本采购订单签署原件一式两份，双方各持一份。',
    '二、验收标准:按乙方所寄样板及国家出口标准作为验收标准。',
    '三、交货期限:交货期限必须严格执行。',
    '四、交货地点:甲方广州公司地址,如上收货地址。',
    '五、付款方式:甲方通过银行转帐的方式付款,乙方账户信息如上。',
    '六、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '七、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
  ],
  PangeaTaxReimbursement: [
    '三、本采购订单签署原件一式两份，双方各持一份。',
    '四、验收标准:按乙方所寄样板及国家出口标准作为验收标准。',
    '五、交货期限:交货期限必须严格执行。',
    '六、交货地点: 广州市越秀区八旗二马路48号航运大厦1605、1606房',
    '七、付款方式:甲方通过银行转帐的方式付款,乙方账户信息如上。',
    '八、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '九、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
    '十、我司开票资料:',
    '账户名称:庞吉亚国际商务服务(广州)有限公司',
    '统一社会代码:91440101MA9XUQNB4B',
    '公司地址:广州市越秀区八旗二马路48号内自编1号主楼16楼自编1605、1606房 ',
    '公司电话:81609790',
    '基本账户:中国光大银行股份有限公司广州分行越秀支行',
    '账户号码:77910180803936888',
    '开户银行地址:广州市越秀区文德南路69号',
  ],
  AZYTaxReimbursement: [
    '一、本采购订单签署原件一式两份，双方各持一份。',
    '二、验收标准:按乙方所寄样板及国家出口标准作为验收标准。',
    '三、交货期限:交货期限必须严格执行。',
    '四、收货地址:澳竣元代收，广州市越秀区八旗二马路48号航运大厦1902房。',
    '五、付款方式:甲方通过银行转帐的方式付款,乙方账户信息如上。',
    '六、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '七、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
  ],
  FOTTaxReimbursement: [
    '一、本采购订单签署原件一式两份，双方各持一份。',
    '二、验收标准:按乙方所寄样板及国家出口标准作为验收标准。',
    '三、交货期限:交货期限必须严格执行。',
    '四、收货地址:澳竣元代收，广州市越秀区八旗二马路48号航运大厦1902房。',
    '五、付款方式:甲方通过银行转帐的方式付款,乙方账户信息如上。',
    '六、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '七、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
  ],
  PrimePacCommon: [
    '八、质量承诺：如甲方自收到货品之日起一个月内发现货品存在不符合合同约定的瑕疵，乙方应无条件包退包换，承担违约责任。承担违约需双方进行协商，达成解决方案。',
    '九、如因未能按上述标准及期限交货而产生经济损失，将由乙方承担。',
    '十、其他事项：',
    {
      value:
        '1. 乙方应确保最终实际生产数量在合约确定数量±5%以内，同时提供一定数量的备品用于更换运输途中可能出现的损坏品。',
    },
    {
      value:
        '2. 乙方若预计交货时间将出现延误，应立刻通知甲方，与甲方另行约定发货时间并得到甲方确认。如乙方无法确定时间或再度延期，并未告知甲方合理延期原因，甲方有权要求乙方承当相应的违约责任并赔偿甲方相应损失。',
    },
    '十一、凡因执行本合同所发生的或与本合同有关的一切争议，如经友好协商不能解决时，交由广州当地法院进行判决。',
  ],
  PrimePacSoft: [], // 跟 PrimePacCommon 完全相同
})

export const appendixData: any[] = [
  '产品制作要求及质量检验标准：',
  {
    value:
      '1、乙方必须严格按甲方要求或产品销售国家/产品出口国最新的相关国家、行业标准对产品质量进行监控和检验。如在现场检验中发现乙方提供的产品不符合合同约定或与样板不符，乙方应在甲方要求的期限内补足、更换。补足、更换后的产品应符合合同要求。',
  },
  {
    value:
      '2、出货前甲方对合同项下产品按GB/T2828.1—2012抽样方法进行抽检，采用Ⅱ级检验水准，AQL值为：严重质量缺陷=1.0，重要质量缺陷=2.5，轻微质量缺陷=4.0 作为标准, 若检验不合格，甲方有权拒收整批货品。乙方应及时采取有效的措施补救，确保合同项下产品在合同交货期内按质、按量交货。如发生延误，则按本合同第七条的约定处理。',
  },
]

export const warehouseList = ref<string[]>([
  'AU Warehouse',
  'GZ Warehouse',
  'UK Warehouse',
  'B Dynamic',
  'TSO',
  'SZ Warehouse',
  'Dynamic Screenprint',
  'AUE',
  'Cleverpak',
  'Alex Pad Printing',
  'RNJ Printing Specialty',
  'Disability Services Australia Limited',
])

/**
 * 测试用的产品黑名单, 不应该出现在生产上的商品.
 */
export const productBlackList = ['4791186000046982872', '4791186000046982896']

interface PrimePacTable {
  project: string
  method: string
}
export const PrimePacCommonRuleTableData = [
  {
    project: '检验项目',
    method: '产品质量检测方法与标准',
  },
  {
    project: '尺寸',
    method: '参考上述产品尺寸',
  },
  {
    project: '印刷',
    method:
      '1、成品整洁，无明显印刷瑕疵范畴的脏污、残缺、刀丝；\n2、文字印刷清晰完整，印迹边缘光洁，渐变区域清晰均匀；\n3、无明显变形和残缺，套印基本准确，同色之间基本无色差；',
  },
  {
    project: '复合',
    method: '无明显气泡，无分层',
  },
  {
    project: '表面',
    method: '平整，无明显气泡，无刮花，无明显溢胶',
  },
  {
    project: '其他',
    method: '不允许出现划伤、烫伤、穿孔、异味、粘连异物、脏污',
  },
  {
    project: '特殊',
    method: '/',
  },
]
// 软包版表格数据
export const PrimePacSoftRuleTableData1: PrimePacTable[] = [
  {
    project: '检验项目',
    method: '产品质量检测方法与标准',
  },
  {
    project: '印刷',
    method:
      '1、成品整洁，无明显印刷瑕疵范畴的脏污、残缺、刀丝；\n2、文字印刷清晰完整，印迹边缘光洁，渐变区域清晰均匀；\n3、无明显变形和残缺，套印基本准确，同色之间基本无色差；\n4、与颜色标准无明显色差（将提供明确的颜色标准）',
  },
  {
    project: '复合',
    method: '无明显气泡，无分层',
  },
  {
    project: '热封',
    method: '平整，无虚封，无明显气泡',
  },
  {
    project: '其他',
    method: '不允许出现划伤、烫伤、穿孔、异味、粘连异物、脏污',
  },
]
export const PrimePacSoftRuleTableData2: PrimePacTable[] = [
  {
    project: '溶剂残留量',
    method:
      '按照GB/T 10004的6.6.17条规定执行\n总溶剂残留量≤10mg/m2\n苯系溶剂残留量≤2mg/m2',
  },
  {
    project: '复合强度',
    method: '按照GB/T 8808的规定执行\n≥1.0   N/15mm',
  },
  {
    project: '热封强度',
    method: '按照GB/T 2358的规定执行\n≥20   N/15mm',
  },
  {
    project: '耐压性能',
    method: '按照GB/T 10004的6.6.8条规定执行\n120N下无渗漏，无破裂',
  },
  {
    project: '熟化时间',
    method: '熟化时间不少于48小时',
  },
]
